@@ -133,12 +133,12 @@ static void diagram_to_lifeline_consistency(void)
         data_diagram_destroy ( &child_diagram );
     }
 
-    /* create a classifier of type DATA_CLASSIFIER_TYPE_UML_CLASS */
+    /* create a classifier of type DATA_CLASSIFIER_TYPE_CLASS */
     data_row_id_t classifier_id;
     {
         data_classifier_t new_classifier;
         data_err = data_classifier_init_new ( &new_classifier,
-                                              DATA_CLASSIFIER_TYPE_UML_CLASS,
+                                              DATA_CLASSIFIER_TYPE_CLASS,
                                               "",  /* stereotype */
                                               "my_class",
                                               "",  /* description */
@@ -311,12 +311,12 @@ static void diagramelement_to_lifeline_consistency(void)
         data_diagram_destroy ( &root_diagram );
     }
 
-    /* create a classifier of type DATA_CLASSIFIER_TYPE_UML_CLASS */
+    /* create a classifier of type DATA_CLASSIFIER_TYPE_CLASS */
     data_row_id_t classifier_id;
     {
         data_classifier_t new_classifier;
         data_err = data_classifier_init_new ( &new_classifier,
-                                              DATA_CLASSIFIER_TYPE_UML_CLASS,
+                                              DATA_CLASSIFIER_TYPE_CLASS,
                                               "",  /* stereotype */
                                               "my_class",
                                               "",  /* description */
