@@ -99,7 +99,7 @@ static void set_up(void)
     data_classifier_t current_classifier;
     data_err = data_classifier_init ( &current_classifier,
                                       12 /*=classifier id*/,
-                                      DATA_CLASSIFIER_TYPE_UML_INTERFACE,
+                                      DATA_CLASSIFIER_TYPE_INTERFACE,
                                       "stereotype-12",
                                       "name-12",
                                       "description-12",
@@ -115,7 +115,7 @@ static void set_up(void)
     data_classifier_t second_classifier;
     data_err = data_classifier_init ( &second_classifier,
                                       13 /*=classifier id*/,
-                                      DATA_CLASSIFIER_TYPE_UML_INTERFACE,
+                                      DATA_CLASSIFIER_TYPE_INTERFACE,
                                       "stereotype-13",
                                       "name-13",
                                       "description-13",
@@ -313,6 +313,16 @@ static void test_search_diagrams(void)
                                                                   );
     TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, data_err );
     TEST_ASSERT_EQUAL_INT( 2, out_diagram_count );
+    
+    /* test 5 */
+    data_small_set_t out_showing_diagram_ids;
+    data_small_set_init( &out_showing_diagram_ids );
+    data_err = data_database_reader_get_diagram_ids_by_classifier_id ( &db_reader,
+                                                                       12,
+                                                                       &out_showing_diagram_ids
+                                                                     );
+    TEST_ASSERT_EQUAL_INT( DATA_ERROR_NONE, data_err );
+    TEST_ASSERT_EQUAL_INT( 2, data_small_set_get_count( &out_showing_diagram_ids ) );
 }
 
 static void test_search_diagramelements(void)
