@@ -6,9 +6,6 @@
 #include <gtk/gtk.h>
 #include <assert.h>
 
-    gui_type_resource_t type_name_icon_list[GUI_RESOURCE_SELECTOR_MAX_TYPES];
-
-
 void gui_resource_selector_init ( gui_resource_selector_t *this_, gui_resources_t *resources )
 {
     TRACE_BEGIN();
@@ -98,29 +95,32 @@ void gui_resource_selector_init ( gui_resource_selector_t *this_, gui_resources_
         gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_CONSTRAINT_BLOCK, "Constraint Block", icon_clas_constraint );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_node = gui_resources_get_type_clas_node( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_NODE, "Node", icon_clas_node );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_NODE, "Node", icon_clas_node );
+        current = &((*this_).type_name_icon_list[idx]); idx++;
+        const GdkPixbuf *icon_clas_subsystem = gui_resources_get_type_clas_subsystem( (*this_).resources );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_SUBSYSTEM, "Subsystem", icon_clas_subsystem );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_component = gui_resources_get_type_clas_component( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_COMPONENT, "Component", icon_clas_component );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_COMPONENT, "Component", icon_clas_component );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_part = gui_resources_get_type_clas_part( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_PART, "Part (component instance)", icon_clas_part );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_PART, "Part (component instance)", icon_clas_part );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_class = gui_resources_get_type_clas_class( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_INTERFACE, "Interface", icon_clas_class );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_INTERFACE, "Interface", icon_clas_class );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_package = gui_resources_get_type_clas_package( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_PACKAGE, "Package", icon_clas_package );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_PACKAGE, "Package", icon_clas_package );
         current = &((*this_).type_name_icon_list[idx]); idx++;
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_CLASS, "Class", icon_clas_class );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_CLASS, "Class", icon_clas_class );
         current = &((*this_).type_name_icon_list[idx]); idx++;
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_OBJECT, "Object (class instance)", icon_clas_part );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_OBJECT, "Object (class instance)", icon_clas_part );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_artifact = gui_resources_get_type_clas_artifact( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_ARTIFACT, "Artifact", icon_clas_artifact );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_ARTIFACT, "Artifact", icon_clas_artifact );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_comment = gui_resources_get_type_clas_comment( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_COMMENT, "Comment", icon_clas_comment );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_COMMENT, "Comment", icon_clas_comment );
         /* requirements classifiers: */
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_requirement = gui_resources_get_type_clas_requirement( (*this_).resources );
@@ -128,19 +128,16 @@ void gui_resource_selector_init ( gui_resource_selector_t *this_, gui_resources_
         /* behavioral classifiers: */
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_actor = gui_resources_get_type_clas_actor( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_ACTOR, "Actor", icon_clas_actor );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_ACTOR, "Actor", icon_clas_actor );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_usecase = gui_resources_get_type_clas_usecase( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_USE_CASE, "Use Case", icon_clas_usecase );
-        current = &((*this_).type_name_icon_list[idx]); idx++;
-        const GdkPixbuf *icon_clas_boundary = gui_resources_get_type_clas_boundary( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_SYSTEM_BOUNDARY, "System Boundary", icon_clas_boundary );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_USE_CASE, "Use Case", icon_clas_usecase );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_diagram = gui_resources_get_type_clas_diagram( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_DIAGRAM_REFERENCE, "Diagram Reference", icon_clas_diagram );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_DIAGRAM_REFERENCE, "Interaction Diagram Reference", icon_clas_diagram );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_state = gui_resources_get_type_clas_state( (*this_).resources );
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_ACTIVITY, "Activity", icon_clas_state );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_ACTIVITY, "Activity", icon_clas_state );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_region = gui_resources_get_type_clas_region( (*this_).resources );
         gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_DYN_INTERRUPTABLE_REGION, "Interruptable Region", icon_clas_region );
@@ -169,7 +166,7 @@ void gui_resource_selector_init ( gui_resource_selector_t *this_, gui_resources_
         const GdkPixbuf *icon_clas_final = gui_resources_get_type_clas_final( (*this_).resources );
         gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_DYN_FINAL_NODE, "Final Node", icon_clas_final );
         current = &((*this_).type_name_icon_list[idx]); idx++;
-        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_UML_STATE, "State", icon_clas_state );
+        gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_STATE, "State", icon_clas_state );
         current = &((*this_).type_name_icon_list[idx]); idx++;
         const GdkPixbuf *icon_clas_history = gui_resources_get_type_clas_history( (*this_).resources );
         gui_type_resource_init_classifier( current, DATA_CLASSIFIER_TYPE_DYN_SHALLOW_HISTORY, "Shallow History", icon_clas_history );
