@@ -10,17 +10,18 @@
 
 void io_export_model_traversal_init( io_export_model_traversal_t *this_,
                                      data_database_reader_t *db_reader,
+                                     data_visible_set_t *input_data,
                                      data_stat_t *io_export_stat,
-                                     xmi_element_writer_t *format_writer )
+                                     xmi_element_writer_t *out_element_writer )
 {
     TRACE_BEGIN();
     assert( NULL != db_reader );
     assert( NULL != io_export_stat );
-    assert( NULL != format_writer );
+    assert( NULL != out_element_writer );
 
     (*this_).db_reader = db_reader;
     (*this_).export_stat = io_export_stat;
-    (*this_).format_writer = format_writer;
+    (*this_).element_writer = out_element_writer;
 
     universal_array_list_init ( &((*this_).written_id_set),
                                 sizeof((*this_).written_id_set_buf)/sizeof(data_id_t),
@@ -32,6 +33,13 @@ void io_export_model_traversal_init( io_export_model_traversal_t *this_,
                                 (void (*)(void *)) &data_id_destroy
                               );
 
+    io_export_interaction_traversal_init( &((*this_).interaction_helper),
+                                          db_reader,
+                                          input_data,
+                                          &((*this_).written_id_set),
+                                          io_export_stat,
+                                          out_element_writer
+                                        );
     TRACE_END();
 }
 
@@ -39,6 +47,8 @@ void io_export_model_traversal_destroy( io_export_model_traversal_t *this_ )
 {
     TRACE_BEGIN();
 
+    io_export_interaction_traversal_destroy ( &((*this_).interaction_helper) );
+    
     universal_array_list_destroy ( &((*this_).written_id_set) );
 
     (*this_).db_reader = NULL;
@@ -75,7 +85,7 @@ int io_export_model_traversal_walk_model_nodes ( io_export_model_traversal_t *th
                 else
                 {
                     write_err |= io_export_model_traversal_private_walk_node ( this_,
-                                                                               DATA_CLASSIFIER_TYPE_UML_PACKAGE, /* a uml:Model is a uml:Package*/
+                                                                               DATA_CLASSIFIER_TYPE_PACKAGE, /* a uml:Model is a uml:Package*/
                                                                                DATA_ID_VOID,
                                                                                data_classifier_get_data_id( &((*this_).temp_classifier) ),
                                                                                0 /* initial recursion_depth */
@@ -107,10 +117,10 @@ int io_export_model_traversal_private_walk_node ( io_export_model_traversal_t *t
     int write_err = 0;
 
     /* initially define flags and attributes */
-    const bool duplicate_classifier
+    bool duplicate_classifier
         =( -1 != universal_array_list_get_index_of( &((*this_).written_id_set), &classifier_id ) );
     bool is_classifier_compliant_here = false;  /* a default value */
-    data_classifier_type_t classifier_type = DATA_CLASSIFIER_TYPE_UML_PACKAGE;  /* a default value */
+    data_classifier_type_t classifier_type = DATA_CLASSIFIER_TYPE_PACKAGE;  /* a default value */
 
     /* the id-sets needed on the stack during recursion */
     data_small_set_t contained_classifiers;
@@ -137,7 +147,25 @@ int io_export_model_traversal_private_walk_node ( io_export_model_traversal_t *t
             const data_classifier_t *const classifier
                 = data_node_set_get_classifier_const ( &((*this_).temp_node_data) );
             classifier_type = data_classifier_get_main_type( classifier );
-            is_classifier_compliant_here = xmi_element_writer_can_classifier_nest_classifier ( (*this_).format_writer,
+            
+            /* fake and export interactions in which the current node is participant first */
+            /* recursion trick: If classifier is nested, this block is evaluated
+             * 1x for the nested classifier and 1x for same classifier at the toplevel model package
+             */
+            {
+                /* write the relationships that can be stated after the classifier or in the toplevel package */
+                write_err |= io_export_model_traversal_private_fake_interactions_of_node( this_,
+                                                                                          parent_type,
+                                                                                          &((*this_).temp_node_data)
+                                                                                        );
+                /* check if the classifier is already written */
+                duplicate_classifier
+                    =( -1 != universal_array_list_get_index_of( &((*this_).written_id_set), &classifier_id ) );            
+            }
+            
+            
+            
+            is_classifier_compliant_here = xmi_element_writer_can_classifier_nest_classifier ( (*this_).element_writer,
                                                                                                parent_type,
                                                                                                classifier_type
                                                                                              );
@@ -147,7 +175,7 @@ int io_export_model_traversal_private_walk_node ( io_export_model_traversal_t *t
                 is_classifier_compliant_here = true;
             }
 
-            if ( is_classifier_compliant_here )
+            if (( ! duplicate_classifier )&&( is_classifier_compliant_here ))
             {
                 /* add this classifier to the already written elements */
                 write_err |= universal_array_list_append( &((*this_).written_id_set), &classifier_id );
@@ -222,7 +250,7 @@ int io_export_model_traversal_private_walk_node ( io_export_model_traversal_t *t
              * 1x for the nested from-/to- classifier and 1x for same classifier at the toplevel model package
              */
             {
-                /* write the relationships that can be stated after the classifier */
+                /* write the relationships that can be stated after the classifier or in the toplevel package */
                 write_err |= io_export_model_traversal_private_iterate_node_relationships( this_,
                                                                                            true,
                                                                                            parent_type,
@@ -253,8 +281,8 @@ int io_export_model_traversal_private_begin_node ( io_export_model_traversal_t *
     const data_classifier_t *const classifier
         = data_node_set_get_classifier_const ( node_data );
 
-    write_err |= xmi_element_writer_start_nested_classifier( (*this_).format_writer, parent_type, classifier );
-    write_err |= xmi_element_writer_write_classifier( (*this_).format_writer, parent_type, classifier );
+    write_err |= xmi_element_writer_start_classifier( (*this_).element_writer, parent_type, classifier );
+    write_err |= xmi_element_writer_assemble_classifier( (*this_).element_writer, parent_type, classifier );
 
     TRACE_END_ERR( write_err );
     return write_err;
@@ -349,7 +377,7 @@ int io_export_model_traversal_private_end_node ( io_export_model_traversal_t *th
     const data_classifier_t *const classifier
         = data_node_set_get_classifier_const ( node_data );
 
-    write_err |= xmi_element_writer_end_nested_classifier( (*this_).format_writer, parent_type, classifier );
+    write_err |= xmi_element_writer_end_classifier( (*this_).element_writer, parent_type, classifier );
 
     TRACE_END_ERR( write_err );
     return write_err;
@@ -376,10 +404,24 @@ int io_export_model_traversal_private_iterate_node_features ( io_export_model_tr
         feature = data_node_set_get_feature_const ( node_data, index );
         if (( feature != NULL ) && ( data_feature_is_valid( feature ) ))
         {
-            write_err |=  xmi_element_writer_write_feature( (*this_).format_writer,
-                                                            data_classifier_get_main_type( classifier ),
-                                                            feature
-                                                          );
+            const bool is_lifeline
+                =( DATA_FEATURE_TYPE_LIFELINE == data_feature_get_main_type( feature ) );
+
+            if ( ! is_lifeline )
+            {
+                write_err |= xmi_element_writer_start_feature( (*this_).element_writer,
+                                                               data_classifier_get_main_type( classifier ),
+                                                               feature
+                                                             );
+                write_err |= xmi_element_writer_assemble_feature( (*this_).element_writer,
+                                                                  data_classifier_get_main_type( classifier ),
+                                                                  feature
+                                                                );
+                write_err |= xmi_element_writer_end_feature( (*this_).element_writer,
+                                                             data_classifier_get_main_type( classifier ),
+                                                             feature
+                                                           );
+            }
         }
         else
         {
@@ -429,7 +471,7 @@ int io_export_model_traversal_private_iterate_node_relationships ( io_export_mod
 
                 const data_relationship_type_t r_type = data_relationship_get_main_type( relation );
                 const bool is_relationship_compliant_here
-                    = xmi_element_writer_can_classifier_nest_relationship( (*this_).format_writer, nesting_type, r_type );
+                    = xmi_element_writer_can_classifier_nest_relationship( (*this_).element_writer, nesting_type, r_type );
                 const data_id_t from_feature_id = data_relationship_get_from_feature_data_id( relation );
                 const bool from_here
                     = ( ( ! data_id_is_valid( &from_feature_id ) )
@@ -445,7 +487,7 @@ int io_export_model_traversal_private_iterate_node_relationships ( io_export_mod
                     = nested_to_foreign_node && source_already_written && is_relationship_compliant_here;
                 const bool foreign_red_ok
                     = nested_to_foreign_node && source_already_written && destination_already_written
-                    && ( nesting_type == DATA_CLASSIFIER_TYPE_UML_PACKAGE );
+                    && ( nesting_type == DATA_CLASSIFIER_TYPE_PACKAGE );
 
                 /* in uml, the source is the dependant, the destination has no link to the source
                  */
@@ -457,7 +499,66 @@ int io_export_model_traversal_private_iterate_node_relationships ( io_export_mod
                     write_err |= universal_array_list_append( &((*this_).written_id_set), &relation_id );
 
                     /* destination classifier found, print the relation */
-                    write_err |= xmi_element_writer_write_relationship( (*this_).format_writer, nesting_type, relation );
+                    write_err |= xmi_element_writer_start_relationship( (*this_).element_writer, nesting_type, relation );
+                    write_err |= xmi_element_writer_assemble_relationship( (*this_).element_writer, nesting_type, local_ok, relation );
+                    write_err |= xmi_element_writer_end_relationship( (*this_).element_writer, nesting_type, relation );
+                }
+            }
+        }
+        else
+        {
+            assert( false );
+        }
+    }
+
+    TRACE_END_ERR( write_err );
+    return write_err;
+}
+
+int io_export_model_traversal_private_fake_interactions_of_node ( io_export_model_traversal_t *this_,
+                                                                  data_classifier_type_t nesting_type,
+                                                                  const data_node_set_t *node_data )
+{
+    TRACE_BEGIN();
+    assert( node_data != NULL );
+    assert( data_node_set_is_valid( node_data ) );
+    int write_err = 0;
+
+    const data_classifier_t *const classifier
+        = data_node_set_get_classifier_const ( node_data );
+    const data_id_t classifier_id = data_classifier_get_data_id( classifier );
+
+    /* iterate over all features, search for lifelines */
+    const uint32_t count = data_node_set_get_feature_count ( node_data );
+    for ( uint32_t index = 0; index < count; index ++ )
+    {
+        /* get feature */
+        const data_feature_t *feature;
+        feature = data_node_set_get_feature_const ( node_data, index );
+        if (( feature != NULL ) && ( data_feature_is_valid( feature ) ))
+        {
+            /* determine if the feature is a duplicate */
+            const data_id_t feature_id = data_feature_get_data_id( feature );
+            const bool duplicate_feature
+                = ( -1 != universal_array_list_get_index_of( &((*this_).written_id_set), &feature_id ) );
+                
+            /* determine if the feature is a lifeline */
+            const data_feature_type_t feat_type = data_feature_get_main_type( feature );
+            const bool is_lifeline = ( feat_type == DATA_FEATURE_TYPE_LIFELINE );
+            
+            if (( ! duplicate_feature )&&( is_lifeline ))  /* just an optimization, checked again by (*this_).interaction_helper */
+            {
+                static const data_classifier_type_t FAKE_INTERACTION 
+                    = DATA_CLASSIFIER_TYPE_CLASS; /* interaction is subclass of class */
+                const bool is_interaction_compliant_here
+                    = xmi_element_writer_can_classifier_nest_classifier( (*this_).element_writer, nesting_type, FAKE_INTERACTION );
+
+                if ( is_interaction_compliant_here && (IO_WRITER_PASS_BASE==xmi_element_writer_get_mode( (*this_).element_writer ) ))
+                {
+                    write_err |=  io_export_interaction_traversal_iterate_classifier_occurrences( &((*this_).interaction_helper),
+                                                                                                  nesting_type,
+                                                                                                  classifier_id
+                                                                                                );
                 }
             }
         }
