@@ -52,7 +52,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_ACTOR] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: UseCases */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_ACTOR,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_ACTOR,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "Actor",
@@ -63,7 +63,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_USE_CASE] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: UseCases */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_USE_CASE,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_USE_CASE,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "UseCase",
@@ -72,13 +72,13 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .property_to              = NULL,
         .additional_properties    = NULL,
     },
-    [XMI_ELEMENT_INFO_MAP_INDEX_SYSTEM_BOUNDARY] = {
+    [XMI_ELEMENT_INFO_MAP_INDEX_SUBSYSTEM] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: Deployments */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_SYSTEM_BOUNDARY,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_SUBSYSTEM,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Node", /* TODO: check type */
-        .is_a                     = (XMI_ELEMENT_IS_A_NODE),
+        .base_name                = "Component",
+        .is_a                     = (XMI_ELEMENT_IS_A_CLASS),
         .property_from            = NULL,
         .property_to              = NULL,
         .additional_properties    = NULL,
@@ -86,10 +86,10 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_ACTIVITY] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: Activities */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 15.7.1 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_ACTIVITY,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_ACTIVITY,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
-        .base_name                = "Activity",  /* TODO: check type, isn't this an Action? */
+        .base_name                = "Activity",
         .is_a                     = (XMI_ELEMENT_IS_A_BEHAVIOR),
         .property_from            = NULL,
         .property_to              = NULL,
@@ -98,7 +98,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_STATEMACHINE] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: StateMachines */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 14.5.10 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_STATE,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_STATE,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "StateMachine",
@@ -110,7 +110,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_STATE] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: StateMachines */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 14.5.9 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_STATE,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_STATE,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "State",
@@ -119,14 +119,13 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .property_to              = NULL,
         .additional_properties    = NULL,
     },
-    [XMI_ELEMENT_INFO_MAP_INDEX_DIAGRAM_REFERENCE] = {
-        /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: Activities */
-        /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 15.7.1 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_DIAGRAM_REFERENCE,
+    [XMI_ELEMENT_INFO_MAP_INDEX_INTERACTION_USE] = {
+        /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 17.12.16 */
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_DIAGRAM_REFERENCE,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
-        .base_name                = "Activity",  /* TODO: check type, should be an Interaction Occurrence */
-        .is_a                     = (XMI_ELEMENT_IS_A_BEHAVIOR),
+        .base_name                = "InteractionUse",
+        .is_a                     = (XMI_ELEMENT_IS_A_INTERACTION_FRAGMENT),
         .property_from            = NULL,
         .property_to              = NULL,
         .additional_properties    = NULL,
@@ -134,7 +133,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_NODE] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: Deployments */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 19.5.10 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_NODE,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_NODE,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
         .base_name                = "Node",
@@ -146,7 +145,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_COMPONENT] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: StructuredClassifiers */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 11.8.6 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_COMPONENT,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_COMPONENT,
         .specification            = XMI_SPEC_UML,
         .profile_name             = NULL,
         .base_name                = "Component",
@@ -158,7 +157,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_INTERFACE] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: SimpleClassifiers */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 10.5.5 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_INTERFACE,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_INTERFACE,
         .specification            = XMI_SPEC_UML,
         .profile_name             = NULL,
         .base_name                = "Interface",
@@ -170,7 +169,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_PACKAGE] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: Packages */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 12.4.5 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_PACKAGE,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_PACKAGE,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "Package",
@@ -181,7 +180,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_CLASS] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: StructuredClassifiers */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_CLASS,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_CLASS,
         .specification            = XMI_SPEC_UML,
         .profile_name             = NULL,
         .base_name                = "Class",
@@ -193,7 +192,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     [XMI_ELEMENT_INFO_MAP_INDEX_ARTIFACT] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: Deployments */
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 19.5.1 */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_ARTIFACT,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_ARTIFACT,
         .specification            = XMI_SPEC_UML,
         .profile_name             = NULL,
         .base_name                = "Artifact",
@@ -204,7 +203,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_COMMENT] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: CommonStructure */
-        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_UML_COMMENT,
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_COMMENT,
         .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
         .profile_name             = NULL,
         .base_name                = "Comment",
@@ -412,7 +411,18 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         /* "Signal"; */
         /*.is_a                     = (XMI_ELEMENT_IS_A_CLASSIFIER), */
     },
-
+    [XMI_ELEMENT_INFO_MAP_INDEX_INTERACTION] = {
+        /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 17.2 */
+        .data_type_checksum       = (int) DATA_CLASSIFIER_TYPE_INTERACTION,
+        .specification            = (XMI_SPEC_UML | XMI_SPEC_SYSML),
+        .profile_name             = NULL,
+        .base_name                = "Interaction",
+        .is_a                     = (XMI_ELEMENT_IS_A_BEHAVIOR),
+        .property_from            = NULL,
+        .property_to              = NULL,
+        .additional_properties    = NULL,
+    },
+    
     /* ================================ FEATURE ================================ */
 
     [XMI_ELEMENT_INFO_MAP_INDEX_PROPERTY] = {
@@ -498,6 +508,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_ASSOCIATION] = {
         /* spec: https://www.omg.org/spec/UML/20161101/UML.xmi (v2.5.1) pkg: StructuredClassifiers */
+        /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 11.8.1 */
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_ASSOCIATION,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
@@ -513,7 +524,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_AGGREGATION,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Association",  /* TODO an Aggregation is an Association with special properties */
+        .base_name                = "Association",
         .is_a                     = (XMI_ELEMENT_IS_A_ASSOCIATION),
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 9.5.3, 9.8.3 */
         .property_from            = "memberEnd",
@@ -525,7 +536,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_COMPOSITION,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Association",  /* TODO a Composition is an Association with property aggregation = composite */
+        .base_name                = "Association",
         .is_a                     = (XMI_ELEMENT_IS_A_ASSOCIATION),
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 9.5.3, 9.8.3 */
         .property_from            = "memberEnd",
@@ -566,11 +577,10 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_ASYNC_CALL,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Interaction",  /* TODO: applicable only in an interaction context, see asynchSignal */
-        /*.base_name                = "Message",*/  /* TODO: applicable only in an interaction context, see asynchSignal */
-        .is_a                     = (XMI_ELEMENT_IS_A_NAMED_ELEMENT),
-        .property_from            = "lifeline",
-        .property_to              = "lifeline",
+        .base_name                = "Message",
+        .is_a                     = (XMI_ELEMENT_IS_A_MESSAGE),
+        .property_from            = "sendEvent",
+        .property_to              = "receiveEvent",
         .additional_properties    = "messageSort=\"asynchSignal\"",
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_SYNC_CALL] = {
@@ -578,23 +588,22 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_SYNC_CALL,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Interaction",  /* TODO: applicable only in an interaction context, see synchCall */
-        /*.base_name                = "Message",*/  /* TODO: applicable only in an interaction context, see synchCall */
-        .is_a                     = (XMI_ELEMENT_IS_A_NAMED_ELEMENT),
-        .property_from            = "lifeline",
-        .property_to              = "lifeline",
-        .additional_properties    = "messageSort=\"synchCall\"",
+        .base_name                = "Message",
+        .is_a                     = (XMI_ELEMENT_IS_A_MESSAGE),
+        .property_from            = "sendEvent",
+        .property_to              = "receiveEvent",
+        /*.additional_properties    = "messageSort=\"synchCall\"",*/  /* this is the default value */
+        .additional_properties    = NULL,
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_RETURN_CALL] = {
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 17.12.18, 17.12.22 */
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_RETURN_CALL,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Interaction",  /* TODO: applicable only in an interaction context, see reply */
-        /*.base_name                = "Message",*/  /* TODO: applicable only in an interaction context, see reply */
-        .is_a                     = (XMI_ELEMENT_IS_A_NAMED_ELEMENT),
-        .property_from            = "lifeline",
-        .property_to              = "lifeline",
+        .base_name                = "Message",
+        .is_a                     = (XMI_ELEMENT_IS_A_MESSAGE),
+        .property_from            = "sendEvent",
+        .property_to              = "receiveEvent",
         .additional_properties    = "messageSort=\"reply\"",
     },
     [XMI_ELEMENT_INFO_MAP_INDEX_COMMUNICATION_PATH] = {
@@ -714,7 +723,7 @@ const xmi_element_info_map_t xmi_element_info_map_standard
         .data_type_checksum       = (int) DATA_RELATIONSHIP_TYPE_UML_CONTAINMENT,
         .specification            = (XMI_SPEC_UML),
         .profile_name             = NULL,
-        .base_name                = "Association",  /* TODO a Composition is an Association with special properties */
+        .base_name                = "Association",
         .is_a                     = (XMI_ELEMENT_IS_A_ASSOCIATION),
         /* spec-ref: https://www.omg.org/spec/UML/2.5.1/PDF chapter 9.5.3, 9.8.3 */
         .property_from            = "memberEnd",
